# BibleMate AI Agentic Skills

Agentic skill files for third-party AI agents.

# Antigravity

To install / update the skill, run `biblematemcpskill -a`

# Claude Code

To install / update the skill, run `biblematemcpskill -c`

# Gemini CLI

To install / update the skill, run `biblematemcpskill -g`

# OpenClaw

To install / update the skill, run `biblematemcpskill -o`